@@ -125,59 +125,57 @@ impl Handler for CompressionHandler {
         {
             return;
         }
-        if let Some(body) = res.take_body() {
-            match body {
-                Body::Empty => {
+        match res.take_body() {
+            Body::None => {
+                return;
+            }
+            Body::Bytes(body) => {
+                if body.len() < self.min_length {
+                    res.set_body(Body::Bytes(body));
                     return;
                 }
-                Body::Bytes(body) => {
-                    if body.len() < self.min_length {
-                        res.set_body(Some(Body::Bytes(body)));
-                        return;
+                let reader = StreamReader::new(tokio_stream::once(Result::<_, IoError>::Ok(body)));
+                match self.algo {
+                    CompressionAlgo::Gzip => {
+                        let stream = ReaderStream::new(GzipEncoder::new(reader));
+                        if let Err(e) = res.streaming(stream) {
+                            tracing::error!(error = ?e, "request streaming error");
+                        }
                     }
-                    let reader = StreamReader::new(tokio_stream::once(Result::<_, IoError>::Ok(body)));
-                    match self.algo {
-                        CompressionAlgo::Gzip => {
-                            let stream = ReaderStream::new(GzipEncoder::new(reader));
-                            if let Err(e) = res.streaming(stream) {
-                                tracing::error!(error = ?e, "request streaming error");
-                            }
+                    CompressionAlgo::Deflate => {
+                        let stream = ReaderStream::new(DeflateEncoder::new(reader));
+                        if let Err(e) = res.streaming(stream) {
+                            tracing::error!(error = ?e, "request streaming error");
                         }
-                        CompressionAlgo::Deflate => {
-                            let stream = ReaderStream::new(DeflateEncoder::new(reader));
-                            if let Err(e) = res.streaming(stream) {
-                                tracing::error!(error = ?e, "request streaming error");
-                            }
-                        }
-                        CompressionAlgo::Brotli => {
-                            let stream = ReaderStream::new(BrotliEncoder::new(reader));
-                            if let Err(e) = res.streaming(stream) {
-                                tracing::error!(error = ?e, "request streaming error");
-                            }
+                    }
+                    CompressionAlgo::Brotli => {
+                        let stream = ReaderStream::new(BrotliEncoder::new(reader));
+                        if let Err(e) = res.streaming(stream) {
+                            tracing::error!(error = ?e, "request streaming error");
                         }
                     }
                 }
-                Body::Stream(body) => {
-                    let body = body.map(|item| item.map_err(|_| ErrorKind::Other));
-                    let reader = StreamReader::new(body);
-                    match self.algo {
-                        CompressionAlgo::Gzip => {
-                            let stream = ReaderStream::new(GzipEncoder::new(reader));
-                            if let Err(e) = res.streaming(stream) {
-                                tracing::error!(error = ?e, "request streaming error");
-                            }
+            }
+            Body::Stream(body) => {
+                let body = body.map(|item| item.map_err(|_| ErrorKind::Other));
+                let reader = StreamReader::new(body);
+                match self.algo {
+                    CompressionAlgo::Gzip => {
+                        let stream = ReaderStream::new(GzipEncoder::new(reader));
+                        if let Err(e) = res.streaming(stream) {
+                            tracing::error!(error = ?e, "request streaming error");
                         }
-                        CompressionAlgo::Deflate => {
-                            let stream = ReaderStream::new(DeflateEncoder::new(reader));
-                            if let Err(e) = res.streaming(stream) {
-                                tracing::error!(error = ?e, "request streaming error");
-                            }
+                    }
+                    CompressionAlgo::Deflate => {
+                        let stream = ReaderStream::new(DeflateEncoder::new(reader));
+                        if let Err(e) = res.streaming(stream) {
+                            tracing::error!(error = ?e, "request streaming error");
                         }
-                        CompressionAlgo::Brotli => {
-                            let stream = ReaderStream::new(BrotliEncoder::new(reader));
-                            if let Err(e) = res.streaming(stream) {
-                                tracing::error!(error = ?e, "request streaming error");
-                            }
+                    }
+                    CompressionAlgo::Brotli => {
+                        let stream = ReaderStream::new(BrotliEncoder::new(reader));
+                        if let Err(e) = res.streaming(stream) {
+                            tracing::error!(error = ?e, "request streaming error");
                         }
                     }
                 }
