@@ -1,9 +1,8 @@
-//! The extra lib of Savlo web server framework.
-//! Read more: <https://salvo.rs>
+//! The extra lib of Savlo web server framework. Read more: <https://salvo.rs>
 #![doc(html_favicon_url = "https://salvo.rs/images/favicon-32x32.png")]
 #![doc(html_logo_url = "https://salvo.rs/images/logo.svg")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
-#![deny(private_in_public, unreachable_pub)]
+#![deny(private_in_public, unreachable_pub, unused_crate_dependencies)]
 #![forbid(unsafe_code)]
 #![warn(missing_docs)]
 
