@@ -13,13 +13,18 @@ pub struct FileHandler(NamedFileBuilder);
 
 impl FileHandler {
     /// Create a new `FileHandler`.
+    #[inline]
     pub fn new(path: impl Into<PathBuf>) -> Self {
         FileHandler(NamedFile::builder(path))
     }
 
     /// During the file chunk read, the maximum read size at one time will affect the
-    /// access experience and the demand for server memory. Please set it according to your own situation.
-    /// The default is 1M
+    /// access experience and the demand for server memory. 
+    /// 
+    /// Please set it according to your own situation.
+    /// 
+    /// The default is 1M.
+    #[inline]
     pub fn chunk_size(self, size: u64) -> Self {
         Self(self.0.with_buffer_size(size))
     }
@@ -27,6 +32,7 @@ impl FileHandler {
 
 #[async_trait]
 impl Handler for FileHandler {
+    #[inline]
     async fn handle(&self, req: &mut Request, depot: &mut Depot, res: &mut Response, ctrl: &mut FlowCtrl) {
         match self.0.clone().build().await {
             Ok(file) => file.write(req, depot, res).await,
